# Changelog

## [Unreleased]

## [0.2.1] - 2025-05-01

### Changed

-   Support dropdown and tags labels with comma 

### Fixed

-   No more double validation of input data

## [0.2.0] - 2025-04-11

### Added

-   Add create_board, create_items, delete_board

### Changed

-   Renamed load to read
-   Renamed save to update

## [0.1.3] - 2025-04-05

## [0.1.2] - 2025-04-05

### Added

-   Start of Changelog

[Unreleased]: https://github.com/boukepostma/mondaytoframe/compare/0.2.1...HEAD

[0.2.1]: https://github.com/boukepostma/mondaytoframe/compare/0.2.0...0.2.1

[0.2.0]: https://github.com/boukepostma/mondaytoframe/compare/0.1.3...0.2.0

[0.1.3]: https://github.com/boukepostma/mondaytoframe/compare/0.1.2...0.1.3

[0.1.2]: https://github.com/boukepostma/mondaytoframe/compare/3a12ba48d334726026efed36f2eb481f415ccc74...0.1.2
